@@ -13,7 +13,7 @@ that makes it easy to keep track of many datasets at once.
 
 import errno
 import os
-from typing import Any, Mapping, Optional, Type, Union
+from typing import Any, Mapping, Optional, Type, Union, cast
 
 import pandas as pd
 import tensorflow as tf
@@ -183,13 +183,13 @@ class DataBlob(DataBlobBase):
     :py:attr:`DataBlob.validation`, and :py:attr:`DataBlob.test`.
 
     >>> datablob.training
-    <ZipDataset shapes: ((3,), (1,)), types: (tf.float32, tf.float32)>
+    <ZipDataset element_spec=(TensorSpec(shape=(3,), dtype=tf.float32, name=None), TensorSpec(shape=(1,), dtype=tf.float32, name=None))>
     >>>
     >>> datablob.validation
-    <ZipDataset shapes: ((3,), (1,)), types: (tf.float32, tf.float32)>
+    <ZipDataset element_spec=(TensorSpec(shape=(3,), dtype=tf.float32, name=None), TensorSpec(shape=(1,), dtype=tf.float32, name=None))>
     >>>
     >>> datablob.test
-    <ZipDataset shapes: ((3,), (1,)), types: (tf.float32, tf.float32)>
+    <ZipDataset element_spec=(TensorSpec(shape=(3,), dtype=tf.float32, name=None), TensorSpec(shape=(1,), dtype=tf.float32, name=None))>
 
     :py:class:`DataBlob` objects have some methods for applying
     :py:mod:`tf.data` transformations to the training, validation, and
@@ -278,6 +278,7 @@ class DataBlob(DataBlobBase):
         *,
         hyperparams: Optional[Union[Mapping[str, Any], HyperparamsType]] = None,
         datablobs_directory: str,
+        cache: bool = False,
         repeat: Union[bool, int, None] = True,
         per_replica_batch_size: Optional[int] = None,
         tf_distribute_strategy: Optional[tf.distribute.Strategy] = None,
@@ -294,6 +295,10 @@ class DataBlob(DataBlobBase):
                 :py:class:`DataBlob` s. The exact filename is calculated
                 from the class name and hyperparams.
 
+            cache: Whether to cache the :py:class:`DataBlob` in memory.
+                If ``repeat`` is also enabled, then caching will
+                happen before repeating.
+
             repeat: Repeats the :py:class:`DataBlob` after loading it.
                 Set to ``True`` to enable infinite repeating.
                 Set to a positive integer ``n`` to repeat the
@@ -313,6 +318,7 @@ class DataBlob(DataBlobBase):
             hyperparams=hyperparams,
             datablobs_directory=datablobs_directory,
             datablob_class=cls,
+            cache=cache,
             repeat=repeat,
             per_replica_batch_size=per_replica_batch_size,
             tf_distribute_strategy=tf_distribute_strategy,
@@ -388,6 +394,7 @@ class DataBlob(DataBlobBase):
         cls,
         *,
         path: str,
+        cache: bool = False,
         repeat: Union[bool, int, None] = True,
         per_replica_batch_size: Optional[int] = None,
         tf_distribute_strategy: Optional[tf.distribute.get_strategy] = None,
@@ -397,6 +404,10 @@ class DataBlob(DataBlobBase):
             path: The exact location of the saved :py:class:`DataBlob`
                 on the filesystem.
 
+            cache: Whether to cache the :py:class:`DataBlob` in memory.
+                If ``repeat`` is also enabled, then caching will
+                happen before repeating.
+
             repeat: Repeats the :py:class:`DataBlob` after loading it.
                 Set to ``True`` to enable infinite repeating.
                 Set to a positive integer ``n`` to repeat the
@@ -415,6 +426,7 @@ class DataBlob(DataBlobBase):
         return _DistributedDataBlobFromExactPath(
             path=path,
             datablob_class=cls,
+            cache=cache,
             repeat=repeat,
             per_replica_batch_size=per_replica_batch_size,
             tf_distribute_strategy=tf_distribute_strategy,
@@ -970,6 +982,9 @@ class DataFrameDataBlob(DataBlob):
     def save_hook(self, *, subtype: str, path: str) -> None:
         super().save_hook(subtype=subtype, path=path)
         dataframe = getattr(self, subtype + "_dataframe", None)
+        if dataframe is None:
+            return
+        dataframe = cast(pd.DataFrame, dataframe)
         dataframe_path = os.path.join(path, _DATAFRAME_FILENAME)
         dataframe.to_pickle(
             path=dataframe_path,
@@ -1686,6 +1701,7 @@ class DistributedDataBlob(DataBlobBase):
         group_name: str,
         hyperparams: Optional[Union[Mapping[str, Any], HyperparamsType]] = None,
         hyperparams_class: Type[HyperparamsType],
+        cache: bool = False,
         repeat: Union[bool, int, None] = True,
         per_replica_batch_size: Optional[int] = None,
         tf_distribute_strategy: Optional[tf.distribute.get_strategy] = None,
@@ -1701,6 +1717,10 @@ class DistributedDataBlob(DataBlobBase):
             hyperparams_class: The :py:class:`HyperparamsType` class that
                 ``hyperparams`` instances are created from.
 
+            cache: Whether to cache the :py:class:`DataBlob` in memory.
+                If ``repeat`` is also enabled, then caching will
+                happen before repeating.
+
             repeat: Repeats the :py:class:`DataBlob` after loading it.
                 Set to ``True`` to enable infinite repeating.
                 Set to a positive integer ``n`` to repeat the
@@ -1722,6 +1742,7 @@ class DistributedDataBlob(DataBlobBase):
         super().__init__(
             hyperparams=hyperparams,
         )
+        self._cache = cache
         self._repeat = repeat
         self._per_replica_batch_size = per_replica_batch_size
         self._tf_distribute_strategy = (
@@ -1775,10 +1796,16 @@ class DistributedDataBlob(DataBlobBase):
             Returns a :py:class:`DataBlob` that has been modified by
                 repeating, batching, or another transformation.
         """
+        # Optionally cache the DataBlob in memory as we iterate over it.
+        if self._cache:
+            datablob = datablob.cache()
+        # Optionally repeat the DataBlob an infinite number of times.
         if self._repeat is True:
             datablob = datablob.repeat()
+        # Or repeat the DataBlob a finite number of times.
         elif self._repeat is not False:
             datablob = datablob.repeat(count=self._repeat)
+        # Optionally batch the DataBlob.
         if self._per_replica_batch_size is not None:
             datablob = datablob.batch(
                 batch_size=self._per_replica_batch_size,
@@ -1885,6 +1912,7 @@ class _DistributedDataBlobFromFilesystem(DistributedDataBlob):
         hyperparams: Optional[Union[Mapping[str, Any], HyperparamsType]] = None,
         datablobs_directory: str,
         datablob_class: Optional[Type[DataBlob]] = None,
+        cache: bool = False,
         repeat: Union[bool, int, None] = True,
         per_replica_batch_size: Optional[int] = None,
         tf_distribute_strategy: Optional[tf.distribute.get_strategy] = None,
@@ -1902,6 +1930,7 @@ class _DistributedDataBlobFromFilesystem(DistributedDataBlob):
             group_name=metadata.group_name,
             hyperparams=metadata.hyperparams,
             hyperparams_class=metadata.hyperparams.__class__,
+            cache=cache,
             repeat=repeat,
             per_replica_batch_size=per_replica_batch_size,
             tf_distribute_strategy=tf_distribute_strategy,
@@ -1928,6 +1957,7 @@ class _DistributedDataBlobFromExactPath(DistributedDataBlob):
         *,
         path: str,
         datablob_class: Optional[Type[DataBlob]] = None,
+        cache: bool = False,
         repeat: Union[bool, int, None] = True,
         per_replica_batch_size: Optional[int] = None,
         tf_distribute_strategy: Optional[tf.distribute.get_strategy] = None,
@@ -1944,6 +1974,7 @@ class _DistributedDataBlobFromExactPath(DistributedDataBlob):
             group_name=metadata.group_name,
             hyperparams=metadata.hyperparams,
             hyperparams_class=metadata.hyperparams.__class__,
+            cache=cache,
             repeat=repeat,
             per_replica_batch_size=per_replica_batch_size,
             tf_distribute_strategy=tf_distribute_strategy,
