@@ -432,6 +432,16 @@ class KerasModel(Model):
         return 0
 
     def save(self, models_directory: str) -> None:
+        # The experimental_custom_gradients save option is only available
+        # on TensorFlow 2.6.0 and newer.
+        try:
+            save_options = (
+                tf.saved_model.SaveOptions(  # pylint: disable=unexpected-keyword-arg
+                    experimental_custom_gradients=True
+                )
+            )
+        except TypeError:
+            save_options = None
         model_path = os.path.join(models_directory, self.name)
         try:
             self._model.save(
@@ -439,6 +449,7 @@ class KerasModel(Model):
                 overwrite=True,
                 include_optimizer=True,
                 save_format="tf",
+                options=save_options,
             )
             history_path = os.path.join(model_path, _HISTORY_FILENAME)
             with open(history_path, "w", encoding="utf-8") as fp:
@@ -554,6 +565,8 @@ class KerasModel(Model):
                 EpochCallback(
                     scalarstop_model=self,
                     logger=logger or _LOGGER,
+                    steps_per_epoch=steps_per_epoch,
+                    validation_steps_per_epoch=validation_steps_per_epoch,
                     models_directory=models_directory,
                     log_epochs=log_epochs,
                     train_store=train_store,
